@@ -1,7 +1,7 @@
 /*
  * Geeqie
  * (C) 2006 John Ellis
- * Copyright (C) 2008 - 2010 The Geeqie Team
+ * Copyright (C) 2008 - 2012 The Geeqie Team
  *
  * Author: John Ellis
  *
@@ -99,7 +99,7 @@ static void bar_sort_collection_list_build(GtkWidget *bookmarks)
 	history_list_free_key(SORT_KEY_COLLECTIONS);
 	bookmark_list_set_key(bookmarks, SORT_KEY_COLLECTIONS);
 
-	dir_fd = file_data_new_simple(get_collections_dir());
+	dir_fd = file_data_new_dir(get_collections_dir());
 	filelist_read(dir_fd, &list, NULL);
 	file_data_unref(dir_fd);
 
@@ -205,18 +205,18 @@ static void bar_sort_undo_folder(SortData *sd, GtkWidget *button)
 			GList *list;
 			gchar *src_dir;
 
-			list = g_list_append(NULL, file_data_new_simple(sd->undo_dest));
+			list = g_list_append(NULL, file_data_new_group(sd->undo_dest));
 			src_dir = remove_level_from_path(sd->undo_src);
 			file_util_move_simple(list, src_dir, sd->lw->window);
 			g_free(src_dir);
 			}
 			break;
 		case BAR_SORT_COPY:
-			file_util_delete(file_data_new_simple(sd->undo_dest), NULL, button);
+			file_util_delete(file_data_new_group(sd->undo_dest), NULL, button);
 			break;
 		default:
 			/* undo external command */
-			file_util_delete(file_data_new_simple(sd->undo_dest), NULL, button);
+			file_util_delete(file_data_new_group(sd->undo_dest), NULL, button);
 			break;
 		}
 
@@ -224,7 +224,7 @@ static void bar_sort_undo_folder(SortData *sd, GtkWidget *button)
 
 	if (isfile(sd->undo_src))
 		{
-		layout_image_set_fd(sd->lw, file_data_new_simple(sd->undo_src));
+		layout_image_set_fd(sd->lw, file_data_new_group(sd->undo_src));
 		}
 
 	bar_sort_undo_set(sd, NULL, NULL, NULL);
@@ -241,7 +241,7 @@ static void bar_sort_undo_collection(SortData *sd)
 
 		source = work->data;
 		work = work->next;
-		collect_manager_remove(file_data_new_simple(source), sd->undo_dest);
+		collect_manager_remove(file_data_new_group(source), sd->undo_dest);
 		}
 
 	bar_sort_undo_set(sd, NULL, NULL, NULL);
@@ -724,7 +724,11 @@ void bar_sort_write_config(GtkWidget *bar, GString *outstr, gint indent)
 	if (!sd) return;
 
 	WRITE_NL(); WRITE_STRING("<bar_sort ");
+#if GTK_CHECK_VERSION(2,20,0)
+	write_bool_option(outstr, indent, "enabled", gtk_widget_get_visible(bar));
+#else
 	write_bool_option(outstr, indent, "enabled", GTK_WIDGET_VISIBLE(bar));
+#endif
 	WRITE_INT(*sd, mode);
 	WRITE_INT(*sd, action);
 	WRITE_INT(*sd, selection);
