@@ -1,7 +1,7 @@
 /*
  * Geeqie
  * (C) 2006 John Ellis
- * Copyright (C) 2008 - 2010 The Geeqie Team
+ * Copyright (C) 2008 - 2012 The Geeqie Team
  *
  * Author: John Ellis
  *
@@ -256,7 +256,11 @@ static void cache_maintain_home_close_cb(GenericDialog *gd, gpointer data)
 {
 	CMData *cm = data;
 
+#if GTK_CHECK_VERSION(2,20,0)
+	if (!gtk_widget_get_sensitive(cm->button_close)) return;
+#else
 	if (!GTK_WIDGET_SENSITIVE(cm->button_close)) return;
+#endif
 
 	cache_maintain_home_close(cm);
 }
@@ -287,7 +291,7 @@ void cache_maintain_home(gboolean metadata, gboolean clear, GtkWidget *parent)
 		cache_folder = get_thumbnails_cache_dir();
 		}
 
-	dir_fd = file_data_new_simple(cache_folder);
+	dir_fd = file_data_new_dir(cache_folder);
 	if (!filelist_read(dir_fd, NULL, &dlist))
 		{
 		file_data_unref(dir_fd);
@@ -366,7 +370,7 @@ gint cache_maintain_home_dir(const gchar *dir, gint recursive, gint clear)
 
 	base_length = strlen(homedir()) + strlen("/") + strlen(GQ_CACHE_RC_THUMB);
 	base = g_strconcat(homedir(), "/", GQ_CACHE_RC_THUMB, dir, NULL);
-	dir_fd = file_data_new_simple(base);
+	dir_fd = file_data_new_dir(base);
 	g_free(base);
 
 	if (filelist_read(dir_fd, &flist, &dlist))
@@ -438,7 +442,7 @@ gint cache_maintain_dir(FileData *dir_fd, gint recursive, gint clear)
 	GList *work;
 
 	cachedir = g_build_filename(dir, GQ_CACHE_LOCAL_THUMB, NULL);
-	cachedir_fd = file_data_new_simple(cachedir);
+	cachedir_fd = file_data_new_dir(cachedir);
 	g_free(cachedir);
 
 	filelist_read(cachedir_fd, &list, NULL);
@@ -708,7 +712,11 @@ static void cache_manager_render_close_cb(GenericDialog *fd, gpointer data)
 {
 	CleanData *cd = data;
 
+#if GTK_CHECK_VERSION(2,20,0)
+	if (!gtk_widget_get_sensitive(cd->button_close)) return;
+#else
 	if (!GTK_WIDGET_SENSITIVE(cd->button_close)) return;
+#endif
 
 	cache_manager_render_reset(cd);
 	generic_dialog_close(cd->gd);
@@ -823,7 +831,11 @@ static void cache_manager_render_start_cb(GenericDialog *fd, gpointer data)
 	CleanData *cd = data;
 	gchar *path;
 
+#if GTK_CHECK_VERSION(2,20,0)
+	if (cd->list || !gtk_widget_get_sensitive(cd->button_start)) return;
+#else
 	if (cd->list || !GTK_WIDGET_SENSITIVE(cd->button_start)) return;
+#endif
 
 	path = remove_trailing_slash((gtk_entry_get_text(GTK_ENTRY(cd->entry))));
 	parse_out_relatives(path);
@@ -844,7 +856,7 @@ static void cache_manager_render_start_cb(GenericDialog *fd, gpointer data)
 
 		spinner_set_interval(cd->spinner, SPINNER_SPEED);
 
-		dir_fd = file_data_new_simple(path);
+		dir_fd = file_data_new_dir(path);
 		cache_manager_render_folder(cd, dir_fd);
 		file_data_unref(dir_fd);
 		while (cache_manager_render_file(cd));
@@ -920,7 +932,11 @@ static void cache_manager_standard_clean_close_cb(GenericDialog *gd, gpointer da
 {
 	CleanData *cd = data;
 
+#if GTK_CHECK_VERSION(2,20,0)
+	if (!gtk_widget_get_sensitive(cd->button_close)) return;
+#else
 	if (!GTK_WIDGET_SENSITIVE(cd->button_close)) return;
+#endif
 
 	generic_dialog_close(cd->gd);
 
@@ -1033,7 +1049,11 @@ static void cache_manager_standard_clean_start_cb(GenericDialog *gd, gpointer da
 	gchar *path;
 	FileData *dir_fd;
 
+#if GTK_CHECK_VERSION(2,20,0)
+	if (cd->list || !gtk_widget_get_sensitive(cd->button_start)) return;
+#else
 	if (cd->list || !GTK_WIDGET_SENSITIVE(cd->button_start)) return;
+#endif
 
 	gtk_widget_set_sensitive(cd->button_start, FALSE);
 	gtk_widget_set_sensitive(cd->button_stop, TRUE);
@@ -1042,21 +1062,21 @@ static void cache_manager_standard_clean_start_cb(GenericDialog *gd, gpointer da
 	gtk_progress_bar_set_text(GTK_PROGRESS_BAR(cd->progress), _("running..."));
 
 	path = g_build_filename(homedir(), THUMB_FOLDER_GLOBAL, THUMB_FOLDER_NORMAL, NULL);
-	dir_fd = file_data_new_simple(path);
+	dir_fd = file_data_new_dir(path);
 	filelist_read(dir_fd, &list, NULL);
 	cd->list = list;
 	file_data_unref(dir_fd);
 	g_free(path);
 
 	path = g_build_filename(homedir(), THUMB_FOLDER_GLOBAL, THUMB_FOLDER_LARGE, NULL);
-	dir_fd = file_data_new_simple(path);
+	dir_fd = file_data_new_dir(path);
 	filelist_read(dir_fd, &list, NULL);
 	cd->list = g_list_concat(cd->list, list);
 	file_data_unref(dir_fd);
 	g_free(path);
 
 	path = g_build_filename(homedir(), THUMB_FOLDER_GLOBAL, THUMB_FOLDER_FAIL, NULL);
-	dir_fd = file_data_new_simple(path);
+	dir_fd = file_data_new_dir(path);
 	filelist_read(dir_fd, &list, NULL);
 	cd->list = g_list_concat(cd->list, list);
 	file_data_unref(dir_fd);
