@@ -1,7 +1,7 @@
 /*
  * Geeqie
  * (C) 2006 John Ellis
- * Copyright (C) 2008 - 2010 The Geeqie Team
+ * Copyright (C) 2008 - 2012 The Geeqie Team
  *
  * Author: John Ellis
  *
@@ -125,7 +125,7 @@ static void parse_command_line_add_file(const gchar *file_path, gchar **path, gc
 		{
 		if (!*path) *path = remove_level_from_path(path_parsed);
 		if (!*file) *file = g_strdup(path_parsed);
-		*list = g_list_prepend(*list, file_data_new_simple(path_parsed));
+		*list = g_list_prepend(*list, file_data_new_group(path_parsed));
 		}
 }
 
@@ -141,7 +141,7 @@ static void parse_command_line_add_dir(const gchar *dir, gchar **path, gchar **f
 
 	path_parsed = g_strdup(dir);
 	parse_out_relatives(path_parsed);
-	dir_fd = file_data_new_simple(path_parsed);
+	dir_fd = file_data_new_dir(path_parsed);
 	
 
 	if (filelist_read(dir_fd, &files, NULL))
@@ -740,6 +740,7 @@ gint main(gint argc, gchar *argv[])
 	g_thread_init(NULL);
 	gdk_threads_init();
 	gdk_threads_enter();
+
 #endif
 	
 	/* init execution time counter (debug only) */
@@ -800,6 +801,10 @@ gint main(gint argc, gchar *argv[])
 	DEBUG_1("%s main: pixbuf_inline_register_stock_icons", get_exec_time());	 
 	pixbuf_inline_register_stock_icons();
 
+	DEBUG_1("%s main: setting default options before commandline handling", get_exec_time());	 
+	options = init_options(NULL);
+	setup_default_options(options);
+
 	DEBUG_1("%s main: parse_command_line", get_exec_time());	 
 	parse_command_line(argc, argv);
 
@@ -817,8 +822,6 @@ gint main(gint argc, gchar *argv[])
 
 	/* restore session from the config file */
 
-	options = init_options(NULL);
-	setup_default_options(options);
 
 	DEBUG_1("%s main: load_options", get_exec_time());	 
 	if (!load_options(options))
