@@ -1,7 +1,7 @@
 /*
  * Geeqie
  * (C) 2006 John Ellis
- * Copyright (C) 2008 - 2010 The Geeqie Team
+ * Copyright (C) 2008 - 2012 The Geeqie Team
  *
  * Author: John Ellis
  *
@@ -305,6 +305,27 @@ static void config_window_apply(void)
 	options->metadata.confirm_on_dir_change = c_options->metadata.confirm_on_dir_change;
 	options->metadata.keywords_case_sensitive = c_options->metadata.keywords_case_sensitive;
 	options->metadata.write_orientation = c_options->metadata.write_orientation;
+	options->stereo.mode = (c_options->stereo.mode & (PR_STEREO_HORIZ | PR_STEREO_VERT | PR_STEREO_FIXED | PR_STEREO_ANAGLYPH | PR_STEREO_HALF)) |
+	                       (c_options->stereo.tmp.mirror_right ? PR_STEREO_MIRROR_RIGHT : 0) |
+	                       (c_options->stereo.tmp.flip_right   ? PR_STEREO_FLIP_RIGHT : 0) |
+	                       (c_options->stereo.tmp.mirror_left  ? PR_STEREO_MIRROR_LEFT : 0) |
+	                       (c_options->stereo.tmp.flip_left    ? PR_STEREO_FLIP_LEFT : 0) |
+	                       (c_options->stereo.tmp.swap         ? PR_STEREO_SWAP : 0) |
+	                       (c_options->stereo.tmp.temp_disable ? PR_STEREO_TEMP_DISABLE : 0);
+	options->stereo.fsmode = (c_options->stereo.fsmode & (PR_STEREO_HORIZ | PR_STEREO_VERT | PR_STEREO_FIXED | PR_STEREO_ANAGLYPH | PR_STEREO_HALF)) |
+	                       (c_options->stereo.tmp.fs_mirror_right ? PR_STEREO_MIRROR_RIGHT : 0) |
+	                       (c_options->stereo.tmp.fs_flip_right   ? PR_STEREO_FLIP_RIGHT : 0) |
+	                       (c_options->stereo.tmp.fs_mirror_left  ? PR_STEREO_MIRROR_LEFT : 0) |
+	                       (c_options->stereo.tmp.fs_flip_left    ? PR_STEREO_FLIP_LEFT : 0) |
+	                       (c_options->stereo.tmp.fs_swap         ? PR_STEREO_SWAP : 0) |
+	                       (c_options->stereo.tmp.fs_temp_disable ? PR_STEREO_TEMP_DISABLE : 0);
+	options->stereo.enable_fsmode = c_options->stereo.enable_fsmode;
+	options->stereo.fixed_w = c_options->stereo.fixed_w;
+	options->stereo.fixed_h = c_options->stereo.fixed_h;
+	options->stereo.fixed_x1 = c_options->stereo.fixed_x1;
+	options->stereo.fixed_y1 = c_options->stereo.fixed_y1;
+	options->stereo.fixed_x2 = c_options->stereo.fixed_x2;
+	options->stereo.fixed_y2 = c_options->stereo.fixed_y2;
 
 #ifdef DEBUG
 	set_debug_level(debug_c);
@@ -528,6 +549,96 @@ static void add_thumb_size_menu(GtkWidget *table, gint column, gint row, gchar *
 	gtk_widget_show(combo);
 }
 
+static void stereo_mode_menu_cb(GtkWidget *combo, gpointer data)
+{
+	gint *option = data;
+
+	switch (gtk_combo_box_get_active(GTK_COMBO_BOX(combo)))
+		{
+		case 0:
+		default:
+			*option = PR_STEREO_NONE;
+			break;
+		case 1:
+			*option = PR_STEREO_ANAGLYPH_RC;
+			break;
+		case 2:
+			*option = PR_STEREO_ANAGLYPH_GRAY;
+			break;
+		case 3:
+			*option = PR_STEREO_ANAGLYPH_DB;
+			break;
+		case 4:
+			*option = PR_STEREO_HORIZ;
+			break;
+		case 5:
+			*option = PR_STEREO_HORIZ | PR_STEREO_HALF;
+			break;
+		case 6:
+			*option = PR_STEREO_VERT;
+			break;
+		case 7:
+			*option = PR_STEREO_VERT | PR_STEREO_HALF;
+			break;
+		case 8:
+			*option = PR_STEREO_FIXED;
+			break;
+		}
+}
+
+static void add_stereo_mode_menu(GtkWidget *table, gint column, gint row, const gchar *text,
+			     guint option, guint *option_c, gboolean add_fixed)
+{
+	GtkWidget *combo;
+	gint current = 0;
+
+	*option_c = option;
+
+	pref_table_label(table, column, row, text, 0.0);
+
+	combo = gtk_combo_box_new_text();
+
+	gtk_combo_box_append_text(GTK_COMBO_BOX(combo), _("Single image"));
+
+	gtk_combo_box_append_text(GTK_COMBO_BOX(combo), _("Anaglyph Red-Cyan"));
+	if (option & PR_STEREO_ANAGLYPH_RC) current = 1;
+	gtk_combo_box_append_text(GTK_COMBO_BOX(combo), _("Anaglyph Gray Red-Cyan"));
+	if (option & PR_STEREO_ANAGLYPH_GRAY) current = 2;
+	gtk_combo_box_append_text(GTK_COMBO_BOX(combo), _("Anaglyph Dubois"));
+	if (option & PR_STEREO_ANAGLYPH_DB) current = 3;
+
+	gtk_combo_box_append_text(GTK_COMBO_BOX(combo), _("Side by Side"));
+	gtk_combo_box_append_text(GTK_COMBO_BOX(combo), _("Side by Side Half size"));
+	if (option & PR_STEREO_HORIZ) 
+		{
+		current = 4;
+		if (option & PR_STEREO_HALF) current = 5;
+		}
+
+	gtk_combo_box_append_text(GTK_COMBO_BOX(combo), _("Top - Bottom"));
+	gtk_combo_box_append_text(GTK_COMBO_BOX(combo), _("Top - Bottom Half size"));
+	if (option & PR_STEREO_VERT) 
+		{
+		current = 6;
+		if (option & PR_STEREO_HALF) current = 7;
+		}
+		
+	if (add_fixed)
+		{
+		gtk_combo_box_append_text(GTK_COMBO_BOX(combo), _("Fixed position"));
+		if (option & PR_STEREO_FIXED) current = 8;
+		}
+
+	gtk_combo_box_set_active(GTK_COMBO_BOX(combo), current);
+
+	g_signal_connect(G_OBJECT(combo), "changed",
+			 G_CALLBACK(stereo_mode_menu_cb), option_c);
+
+	gtk_table_attach(GTK_TABLE(table), combo, column + 1, column + 2, row, row + 1,
+			 GTK_EXPAND | GTK_FILL, 0, 0, 0);
+	gtk_widget_show(combo);
+}
+
 static void filter_store_populate(void)
 {
 	GList *work;
@@ -1964,6 +2075,83 @@ static void config_tab_accelerators(GtkWidget *notebook)
 #endif
 }
 
+/* stereo tab */
+static void config_tab_stereo(GtkWidget *notebook)
+{
+	GtkWidget *vbox;
+	GtkWidget *group;
+	GtkWidget *group2;
+	GtkWidget *table;
+	GtkWidget *box;
+	GtkWidget *box2;
+	GtkWidget *fs_button;
+	vbox = scrolled_notebook_page(notebook, _("Stereo"));
+
+	group = pref_group_new(vbox, FALSE, _("Windowed stereo mode"), GTK_ORIENTATION_VERTICAL);
+
+	table = pref_table_new(group, 2, 1, FALSE, FALSE);
+	add_stereo_mode_menu(table, 0, 0, _("Windowed stereo mode"), options->stereo.mode, &c_options->stereo.mode, FALSE);
+
+	table = pref_table_new(group, 2, 2, TRUE, FALSE);
+	box = pref_table_box(table, 0, 0, GTK_ORIENTATION_HORIZONTAL, NULL);
+	pref_checkbox_new_int(box, _("Mirror left image"),
+			      options->stereo.mode & PR_STEREO_MIRROR_LEFT, &c_options->stereo.tmp.mirror_left);
+	box = pref_table_box(table, 1, 0, GTK_ORIENTATION_HORIZONTAL, NULL);
+	pref_checkbox_new_int(box, _("Flip left image"),
+			      options->stereo.mode & PR_STEREO_FLIP_LEFT, &c_options->stereo.tmp.flip_left);
+	box = pref_table_box(table, 0, 1, GTK_ORIENTATION_HORIZONTAL, NULL);
+	pref_checkbox_new_int(box, _("Mirror right image"),
+			      options->stereo.mode & PR_STEREO_MIRROR_RIGHT, &c_options->stereo.tmp.mirror_right);
+	box = pref_table_box(table, 1, 1, GTK_ORIENTATION_HORIZONTAL, NULL);
+	pref_checkbox_new_int(box, _("Flip right image"),
+			      options->stereo.mode & PR_STEREO_FLIP_RIGHT, &c_options->stereo.tmp.flip_right);
+	pref_checkbox_new_int(group, _("Swap left and right images"),
+			      options->stereo.mode & PR_STEREO_SWAP, &c_options->stereo.tmp.swap);
+	pref_checkbox_new_int(group, _("Disable stereo mode on single image source"),
+			      options->stereo.mode & PR_STEREO_TEMP_DISABLE, &c_options->stereo.tmp.temp_disable);
+
+	group = pref_group_new(vbox, FALSE, _("Fullscreen stereo mode"), GTK_ORIENTATION_VERTICAL);
+	fs_button = pref_checkbox_new_int(group, _("Use different settings for fullscreen"),
+			      options->stereo.enable_fsmode, &c_options->stereo.enable_fsmode);
+	box2 = pref_box_new(group, FALSE, GTK_ORIENTATION_VERTICAL, PREF_PAD_SPACE);
+	pref_checkbox_link_sensitivity(fs_button, box2);
+	table = pref_table_new(box2, 2, 1, FALSE, FALSE);
+	add_stereo_mode_menu(table, 0, 0, _("Fullscreen stereo mode"), options->stereo.fsmode, &c_options->stereo.fsmode, TRUE);
+	table = pref_table_new(box2, 2, 2, TRUE, FALSE);
+	box = pref_table_box(table, 0, 0, GTK_ORIENTATION_HORIZONTAL, NULL);
+	pref_checkbox_new_int(box, _("Mirror left image"),
+			      options->stereo.fsmode & PR_STEREO_MIRROR_LEFT, &c_options->stereo.tmp.fs_mirror_left);
+	box = pref_table_box(table, 1, 0, GTK_ORIENTATION_HORIZONTAL, NULL);
+	pref_checkbox_new_int(box, _("Flip left image"),
+			      options->stereo.fsmode & PR_STEREO_FLIP_LEFT, &c_options->stereo.tmp.fs_flip_left);
+	box = pref_table_box(table, 0, 1, GTK_ORIENTATION_HORIZONTAL, NULL);
+	pref_checkbox_new_int(box, _("Mirror right image"),
+			      options->stereo.fsmode & PR_STEREO_MIRROR_RIGHT, &c_options->stereo.tmp.fs_mirror_right);
+	box = pref_table_box(table, 1, 1, GTK_ORIENTATION_HORIZONTAL, NULL);
+	pref_checkbox_new_int(box, _("Flip right image"),
+			      options->stereo.fsmode & PR_STEREO_FLIP_RIGHT, &c_options->stereo.tmp.fs_flip_right);
+	pref_checkbox_new_int(box2, _("Swap left and right images"),
+			      options->stereo.fsmode & PR_STEREO_SWAP, &c_options->stereo.tmp.fs_swap);
+	pref_checkbox_new_int(box2, _("Disable stereo mode on single image source"),
+			      options->stereo.fsmode & PR_STEREO_TEMP_DISABLE, &c_options->stereo.tmp.fs_temp_disable);
+
+	group2 = pref_group_new(box2, FALSE, _("Fixed position"), GTK_ORIENTATION_VERTICAL);
+	table = pref_table_new(group2, 5, 3, FALSE, FALSE);
+	pref_table_spin_new_int(table, 0, 0, _("Width"), NULL,
+			  1, 5000, 1, options->stereo.fixed_w, &c_options->stereo.fixed_w);
+	pref_table_spin_new_int(table, 3, 0,  _("Height"), NULL,
+			  1, 5000, 1, options->stereo.fixed_h, &c_options->stereo.fixed_h);
+	pref_table_spin_new_int(table, 0, 1,  _("Left X"), NULL,
+			  0, 5000, 1, options->stereo.fixed_x1, &c_options->stereo.fixed_x1);
+	pref_table_spin_new_int(table, 3, 1,  _("Left Y"), NULL,
+			  0, 5000, 1, options->stereo.fixed_y1, &c_options->stereo.fixed_y1);
+	pref_table_spin_new_int(table, 0, 2,  _("Right X"), NULL,
+			  0, 5000, 1, options->stereo.fixed_x2, &c_options->stereo.fixed_x2);
+	pref_table_spin_new_int(table, 3, 2,  _("Right Y"), NULL,
+			  0, 5000, 1, options->stereo.fixed_y2, &c_options->stereo.fixed_y2);
+
+}
+
 /* Main preferences window */
 static void config_window_create(void)
 {
@@ -2036,6 +2224,7 @@ static void config_window_create(void)
 	config_tab_files(notebook);
 	config_tab_metadata(notebook);
 	config_tab_color(notebook);
+	config_tab_stereo(notebook);
 	config_tab_behavior(notebook);
 
 	gtk_widget_show(notebook);
@@ -2125,7 +2314,7 @@ void show_about_window(void)
 	buf = g_strdup_printf(_("%s %s\n\nCopyright (c) 2006 John Ellis\nCopyright (c) %s The Geeqie Team\nwebsite: %s\nemail: %s\n\nReleased under the GNU General Public License"),
 			      GQ_APPNAME,
 			      VERSION,
-			      "2008 - 2010",
+			      "2008 - 2012",
 			      GQ_WEBSITE,
 			      GQ_EMAIL_ADDRESS);
 	label = gtk_label_new(buf);
